==> glibc-2.0.bin.i386.tar.bz2: usr/include/syscall-list.h <==
/* Generated at libc build time from kernel syscall list.  */
#define SYS_write __NR_write
#define SYS_setrlimit __NR_setrlimit
#define SYS_getdents __NR_getdents
#define SYS_umount __NR_umount
#define SYS_munlock __NR_munlock
#define SYS_delete_module __NR_delete_module
#define SYS_fstat __NR_fstat
#define SYS_getpgid __NR_getpgid
#define SYS_setfsgid __NR_setfsgid
#define SYS_chroot __NR_chroot
#define SYS_modify_ldt __NR_modify_ldt
#define SYS_times __NR_times
#define SYS_setpgid __NR_setpgid
#define SYS_getpgrp __NR_getpgrp
#define SYS_break __NR_break
#define SYS_pause __NR_pause
#define SYS_writev __NR_writev
#define SYS_rename __NR_rename
#define SYS_truncate __NR_truncate
#define SYS_profil __NR_profil
#define SYS_waitpid __NR_waitpid
#define SYS_sigreturn __NR_sigreturn
#define SYS_readdir __NR_readdir
#define SYS_fsync __NR_fsync
#define SYS_lstat __NR_lstat
#define SYS_dup2 __NR_dup2
#define SYS_clone __NR_clone
#define SYS_getppid __NR_getppid
#define SYS_close __NR_close
#define SYS_setgid __NR_setgid
#define SYS_bdflush __NR_bdflush
#define SYS_statfs __NR_statfs
#define SYS_mount __NR_mount
#define SYS_sgetmask __NR_sgetmask
#define SYS_idle __NR_idle
#define SYS_sigaction __NR_sigaction
#define SYS_wait4 __NR_wait4
#define SYS_fork __NR_fork
#define SYS_setfsuid __NR_setfsuid
#define SYS_settimeofday __NR_settimeofday
#define SYS_ssetmask __NR_ssetmask
#define SYS_oldfstat __NR_oldfstat
#define SYS_afs_syscall __NR_afs_syscall
#define SYS_exit __NR_exit
#define SYS_sysinfo __NR_sysinfo
#define SYS_symlink __NR_symlink
#define SYS_ioctl __NR_ioctl
#define SYS_ftruncate __NR_ftruncate
#define SYS_sched_getparam __NR_sched_getparam
#define SYS_creat __NR_creat
#define SYS_sched_rr_get_interval __NR_sched_rr_get_interval
#define SYS_fcntl __NR_fcntl
#define SYS_setsid __NR_setsid
#define SYS_mprotect __NR_mprotect
#define SYS_setuid __NR_setuid
#define SYS_gtty __NR_gtty
#define SYS_oldlstat __NR_oldlstat
#define SYS_umask __NR_umask
#define SYS_iopl __NR_iopl
#define SYS_kill __NR_kill
#define SYS_nanosleep __NR_nanosleep
#define SYS_uname __NR_uname
#define SYS_stime __NR_stime
#define SYS_signal __NR_signal
#define SYS_getitimer __NR_getitimer
#define SYS_readv __NR_readv
#define SYS_getpriority __NR_getpriority
#define SYS_msync __NR_msync
#define SYS_link __NR_link
#define SYS_sched_setparam __NR_sched_setparam
#define SYS_getgid __NR_getgid
#define SYS__newselect __NR__newselect
#define SYS_getrusage __NR_getrusage
#define SYS_lock __NR_lock
#define SYS__llseek __NR__llseek
#define SYS_sched_yield __NR_sched_yield
#define SYS_nice __NR_nice
#define SYS_mmap __NR_mmap
#define SYS_get_kernel_syms __NR_get_kernel_syms
#define SYS_setgroups __NR_setgroups
#define SYS_ulimit __NR_ulimit
#define SYS_munmap __NR_munmap
#define SYS_quotactl __NR_quotactl
#define SYS_getrlimit __NR_getrlimit
#define SYS_brk __NR_brk
#define SYS_sched_getscheduler __NR_sched_getscheduler
#define SYS_personality __NR_personality
#define SYS_getpid __NR_getpid
#define SYS_vhangup __NR_vhangup
#define SYS_ioperm __NR_ioperm
#define SYS_mremap __NR_mremap
#define SYS_ptrace __NR_ptrace
#define SYS_dup __NR_dup
#define SYS_getsid __NR_getsid
#define SYS_getegid __NR_getegid
#define SYS_uselib __NR_uselib
#define SYS_olduname __NR_olduname
#define SYS_getuid __NR_getuid
#define SYS_init_module __NR_init_module
#define SYS_ipc __NR_ipc
#define SYS_pipe __NR_pipe
#define SYS_read __NR_read
#define SYS_open __NR_open
#define SYS_setdomainname __NR_setdomainname
#define SYS_setregid __NR_setregid
#define SYS_phys __NR_phys
#define SYS_mpx __NR_mpx
#define SYS_alarm __NR_alarm
#define SYS_flock __NR_flock
#define SYS_sigsuspend __NR_sigsuspend
#define SYS_fdatasync __NR_fdatasync
#define SYS_prof __NR_prof
#define SYS_sysfs __NR_sysfs
#define SYS_sethostname __NR_sethostname
#define SYS_geteuid __NR_geteuid
#define SYS_swapon __NR_swapon
#define SYS_vm86 __NR_vm86
#define SYS_create_module __NR_create_module
#define SYS_execve __NR_execve
#define SYS_utime __NR_utime
#define SYS_reboot __NR_reboot
#define SYS_socketcall __NR_socketcall
#define SYS_fchdir __NR_fchdir
#define SYS_time __NR_time
#define SYS_setreuid __NR_setreuid
#define SYS_select __NR_select
#define SYS_ustat __NR_ustat
#define SYS_mkdir __NR_mkdir
#define SYS_rmdir __NR_rmdir
#define SYS_adjtimex __NR_adjtimex
#define SYS_acct __NR_acct
#define SYS_sched_setscheduler __NR_sched_setscheduler
#define SYS_mlockall __NR_mlockall
#define SYS_fstatfs __NR_fstatfs
#define SYS_stat __NR_stat
#define SYS_sigpending __NR_sigpending
#define SYS_setup __NR_setup
#define SYS_chdir __NR_chdir
#define SYS_swapoff __NR_swapoff
#define SYS_syslog __NR_syslog
#define SYS_fchmod __NR_fchmod
#define SYS_oldstat __NR_oldstat
#define SYS_readlink __NR_readlink
#define SYS_munlockall __NR_munlockall
#define SYS_stty __NR_stty
#define SYS_sync __NR_sync
#define SYS_setitimer __NR_setitimer
#define SYS_fchown __NR_fchown
#define SYS_access __NR_access
#define SYS_sched_get_priority_max __NR_sched_get_priority_max
#define SYS_gettimeofday __NR_gettimeofday
#define SYS_mknod __NR_mknod
#define SYS_sched_get_priority_min __NR_sched_get_priority_min
#define SYS_oldolduname __NR_oldolduname
#define SYS_getgroups __NR_getgroups
#define SYS_chmod __NR_chmod
#define SYS_mlock __NR_mlock
#define SYS_unlink __NR_unlink
#define SYS__sysctl __NR__sysctl
#define SYS_sigprocmask __NR_sigprocmask
#define SYS_lseek __NR_lseek
#define SYS_setpriority __NR_setpriority
#define SYS_ftime __NR_ftime
#define SYS_chown __NR_chown

==> glibc-2.0.4.bin.i386.tar.bz2: usr/include/syscall-list.h <==
/* Generated at libc build time from kernel syscall list.  */
#define SYS_write __NR_write
#define SYS_setrlimit __NR_setrlimit
#define SYS_getdents __NR_getdents
#define SYS_umount __NR_umount
#define SYS_munlock __NR_munlock
#define SYS_delete_module __NR_delete_module
#define SYS_fstat __NR_fstat
#define SYS_getpgid __NR_getpgid
#define SYS_setfsgid __NR_setfsgid
#define SYS_chroot __NR_chroot
#define SYS_modify_ldt __NR_modify_ldt
#define SYS_times __NR_times
#define SYS_setpgid __NR_setpgid
#define SYS_getpgrp __NR_getpgrp
#define SYS_break __NR_break
#define SYS_query_module __NR_query_module
#define SYS_pause __NR_pause
#define SYS_writev __NR_writev
#define SYS_rename __NR_rename
#define SYS_truncate __NR_truncate
#define SYS_profil __NR_profil
#define SYS_waitpid __NR_waitpid
#define SYS_sigreturn __NR_sigreturn
#define SYS_readdir __NR_readdir
#define SYS_fsync __NR_fsync
#define SYS_lstat __NR_lstat
#define SYS_dup2 __NR_dup2
#define SYS_clone __NR_clone
#define SYS_getppid __NR_getppid
#define SYS_close __NR_close
#define SYS_setgid __NR_setgid
#define SYS_bdflush __NR_bdflush
#define SYS_vm86old __NR_vm86old
#define SYS_statfs __NR_statfs
#define SYS_mount __NR_mount
#define SYS_sgetmask __NR_sgetmask
#define SYS_idle __NR_idle
#define SYS_sigaction __NR_sigaction
#define SYS_wait4 __NR_wait4
#define SYS_fork __NR_fork
#define SYS_setfsuid __NR_setfsuid
#define SYS_settimeofday __NR_settimeofday
#define SYS_ssetmask __NR_ssetmask
#define SYS_oldfstat __NR_oldfstat
#define SYS_afs_syscall __NR_afs_syscall
#define SYS_exit __NR_exit
#define SYS_sysinfo __NR_sysinfo
#define SYS_symlink __NR_symlink
#define SYS_ioctl __NR_ioctl
#define SYS_ftruncate __NR_ftruncate
#define SYS_sched_getparam __NR_sched_getparam
#define SYS_creat __NR_creat
#define SYS_setresuid __NR_setresuid
#define SYS_sched_rr_get_interval __NR_sched_rr_get_interval
#define SYS_fcntl __NR_fcntl
#define SYS_setsid __NR_setsid
#define SYS_mprotect __NR_mprotect
#define SYS_setuid __NR_setuid
#define SYS_gtty __NR_gtty
#define SYS_oldlstat __NR_oldlstat
#define SYS_umask __NR_umask
#define SYS_iopl __NR_iopl
#define SYS_kill __NR_kill
#define SYS_nanosleep __NR_nanosleep
#define SYS_uname __NR_uname
#define SYS_stime __NR_stime
#define SYS_signal __NR_signal
#define SYS_getitimer __NR_getitimer
#define SYS_readv __NR_readv
#define SYS_getpriority __NR_getpriority
#define SYS_msync __NR_msync
#define SYS_link __NR_link
#define SYS_sched_setparam __NR_sched_setparam
#define SYS_getgid __NR_getgid
#define SYS__newselect __NR__newselect
#define SYS_getrusage __NR_getrusage
#define SYS_lock __NR_lock
#define SYS__llseek __NR__llseek
#define SYS_sched_yield __NR_sched_yield
#define SYS_nice __NR_nice
#define SYS_mmap __NR_mmap
#define SYS_get_kernel_syms __NR_get_kernel_syms
#define SYS_setgroups __NR_setgroups
#define SYS_ulimit __NR_ulimit
#define SYS_munmap __NR_munmap
#define SYS_quotactl __NR_quotactl
#define SYS_getrlimit __NR_getrlimit
#define SYS_brk __NR_brk
#define SYS_sched_getscheduler __NR_sched_getscheduler
#define SYS_personality __NR_personality
#define SYS_getpid __NR_getpid
#define SYS_vhangup __NR_vhangup
#define SYS_ioperm __NR_ioperm
#define SYS_mremap __NR_mremap
#define SYS_ptrace __NR_ptrace
#define SYS_dup __NR_dup
#define SYS_getsid __NR_getsid
#define SYS_getegid __NR_getegid
#define SYS_uselib __NR_uselib
#define SYS_olduname __NR_olduname
#define SYS_getuid __NR_getuid
#define SYS_init_module __NR_init_module
#define SYS_ipc __NR_ipc
#define SYS_pipe __NR_pipe
#define SYS_read __NR_read
#define SYS_open __NR_open
#define SYS_setdomainname __NR_setdomainname
#define SYS_setregid __NR_setregid
#define SYS_phys __NR_phys
#define SYS_mpx __NR_mpx
#define SYS_alarm __NR_alarm
#define SYS_poll __NR_poll
#define SYS_flock __NR_flock
#define SYS_sigsuspend __NR_sigsuspend
#define SYS_fdatasync __NR_fdatasync
#define SYS_prof __NR_prof
#define SYS_sysfs __NR_sysfs
#define SYS_sethostname __NR_sethostname
#define SYS_geteuid __NR_geteuid
#define SYS_swapon __NR_swapon
#define SYS_vm86 __NR_vm86
#define SYS_create_module __NR_create_module
#define SYS_execve __NR_execve
#define SYS_utime __NR_utime
#define SYS_reboot __NR_reboot
#define SYS_socketcall __NR_socketcall
#define SYS_fchdir __NR_fchdir
#define SYS_getresuid __NR_getresuid
#define SYS_time __NR_time
#define SYS_setreuid __NR_setreuid
#define SYS_select __NR_select
#define SYS_ustat __NR_ustat
#define SYS_mkdir __NR_mkdir
#define SYS_rmdir __NR_rmdir
#define SYS_adjtimex __NR_adjtimex
#define SYS_acct __NR_acct
#define SYS_sched_setscheduler __NR_sched_setscheduler
#define SYS_mlockall __NR_mlockall
#define SYS_fstatfs __NR_fstatfs
#define SYS_stat __NR_stat
#define SYS_sigpending __NR_sigpending
#define SYS_setup __NR_setup
#define SYS_chdir __NR_chdir
#define SYS_swapoff __NR_swapoff
#define SYS_syslog __NR_syslog
#define SYS_fchmod __NR_fchmod
#define SYS_nfsservctl __NR_nfsservctl
#define SYS_oldstat __NR_oldstat
#define SYS_readlink __NR_readlink
#define SYS_munlockall __NR_munlockall
#define SYS_stty __NR_stty
#define SYS_sync __NR_sync
#define SYS_setitimer __NR_setitimer
#define SYS_fchown __NR_fchown
#define SYS_access __NR_access
#define SYS_sched_get_priority_max __NR_sched_get_priority_max
#define SYS_gettimeofday __NR_gettimeofday
#define SYS_mknod __NR_mknod
#define SYS_sched_get_priority_min __NR_sched_get_priority_min
#define SYS_oldolduname __NR_oldolduname
#define SYS_getgroups __NR_getgroups
#define SYS_chmod __NR_chmod
#define SYS_mlock __NR_mlock
#define SYS_unlink __NR_unlink
#define SYS__sysctl __NR__sysctl
#define SYS_sigprocmask __NR_sigprocmask
#define SYS_lseek __NR_lseek
#define SYS_setpriority __NR_setpriority
#define SYS_ftime __NR_ftime
#define SYS_chown __NR_chown
